@@ -361,6 +361,7 @@ class Willie(irc.Bot):
             return False
         if (hasattr(obj, 'commands') or
                 hasattr(obj, 'rule') or
+                hasattr(obj, 'intents') or
                 hasattr(obj, 'interval')):
             return True
         return False
@@ -483,6 +484,10 @@ class Willie(irc.Bot):
                         # The new format is a list of dicts.
                         example = func.example[0]["example"]
                     example = example.replace('$nickname', str(self.nick))
+                    help_prefix = (self.config.core.help_prefix
+                                   or self.config.core.prefix.strip('\\'))
+                    if example[0] != help_prefix:
+                        example = help_prefix + example[len(help_prefix):]
                 if doc or example:
                     for command in func.commands:
                         self.doc[command] = (doc, example)
@@ -682,6 +687,9 @@ class Willie(irc.Bot):
                         continue
                     if self.limit(trigger, func):
                         continue
+                    if (hasattr(func, 'intents') and
+                            trigger.tags.get('intent') not in func.intents):
+                        continue
                     if func.thread:
                         targs = (func, wrapper, trigger)
                         t = threading.Thread(target=self.call, args=targs)
