@@ -12,6 +12,12 @@ from willie.module import NOLIMIT, commands, example, rule
 import json
 import re
 
+import sys
+if sys.version_info.major < 3:
+    from urlparse import unquote
+else:
+    from urllib.parse import unquote
+
 REDIRECT = re.compile(r'^REDIRECT (.*)')
 
 
@@ -90,7 +96,7 @@ def mw_info(bot, trigger, found_match=None):
     server.
     """
     match = found_match or trigger
-    say_snippet(bot, match.group(1), match.group(2), show_url=False)
+    say_snippet(bot, match.group(1), unquote(match.group(2)), show_url=False)
 
 
 @commands('w', 'wiki', 'wik')
